@@ -29,10 +29,14 @@ class DFXPReader(BaseReader):
         captions = {'captions': {}, 'styles': {}}
 
         for div in dfxp_soup.find_all('div'):
-            captions['captions'][div['xml:lang']] = self._translate_div(div)
+            lang = div.attrs.get('xml:lang', 'en')
+            captions['captions'][lang] = self._translate_div(div)
 
         for style in dfxp_soup.find_all('style'):
-            captions['styles'][style['id']] = self._translate_style(style)
+            id = style.attrs.get('id')
+            if not id:
+                id = style.attrs.get('xml:id')
+            captions['styles'][id] = self._translate_style(style)
 
         return captions
 
@@ -66,6 +70,8 @@ class DFXPReader(BaseReader):
     def _translate_time(self, stamp):
         timesplit = stamp.split(':')
         secsplit = timesplit[2].split('.')
+        if len(timesplit) > 3:
+            secsplit.append((int(timesplit[3]) / 30) * 100)
         microseconds = (int(timesplit[0]) * 3600000000 +
                         int(timesplit[1]) * 60000000 +
                         int(secsplit[0]) * 1000000 +
